/*
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2017 NXP
 * All rights reserved.
 * 
 * SPDX-License-Identifier: BSD-3-Clause
 */

#include "fsl_common.h"
#include "fsl_debug_console.h"
#include "board.h"

#include "fsl_tsi_v5.h"
#include "TSI_key.h"

#include "pin_mux.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define LED1_INIT() LED_RED1_INIT(LOGIC_LED_OFF)
#define LED1_ON() LED_RED1_ON()
#define LED1_OFF() LED_RED1_OFF()

/*******************************************************************************
 * Variables
 ******************************************************************************/

/*******************************************************************************
 * Prototypes
 ******************************************************************************/

/*******************************************************************************
 * Code
 ******************************************************************************/

/*!
 * @brief Initiate TSI module
 * This function is used to initiate TSI moudle,set charge current/voltage,
 * oscillator frequency, track TSI baseline through TSI calibration function.
 */
void TSI_init(void)
{
    tsi_mutualCap_config_t config;

    TSI_GetMutualCapModeDefaultConfig(&config);
    config.commonConfig.mode = kTSI_SensingModeSlection_Mutual;
    config.commonConfig.mainClock = kTSI_MainClockSlection_1;
    config.commonConfig.dvolt = kTSI_DvoltOption_0;               /* DVOLT option value  */
    config.commonConfig.cutoff = kTSI_SincCutoffDiv_0;            /* Cutoff divider  */
    config.commonConfig.order = kTSI_SincFilterOrder_1;           /* SINC filter order */
    config.commonConfig.decimation = kTSI_SincDecimationValue_8;  /* SINC decimation value */
    config.commonConfig.chargeNum = kTSI_SscChargeNumValue_4;     /* SSC output bit0's period setting */
    config.commonConfig.noChargeNum = kTSI_SscNoChargeNumValue_2; /* SSC output bit1's period setting */

    config.preCurrent = kTSI_MutualPreCurrent_4uA;
    config.preResistor = kTSI_MutualPreResistor_4k;
    config.senseResistor = kTSI_MutualSenseResistor_10k;

    config.boostCurrent = kTSI_MutualSenseBoostCurrent_0uA;
    config.txDriveMode = kTSI_MutualTxDriveModeOption_0;
    config.pmosLeftCurrent = kTSI_MutualPmosCurrentMirrorLeft_32;
    config.pmosRightCurrent = kTSI_MutualPmosCurrentMirrorRight_1;
    config.nmosCurrent = kTSI_MutualNmosCurrentMirror_1;

    TSI_InitMutualCapMode(TSI, &config);

    TSI_EnableModule(TSI, true);
}

/*!
 * @brief Main function
 */
int main(void)
{
    uint8_t key_event;
    uint8_t touched_key_id = 0xFFU;

    /* Init board hardware. */
    BOARD_InitPins();
    BOARD_BootClockRUN();
    BOARD_InitDebugConsole();

    PRINTF("TSI mutual mode demo.\r\n");

    LED1_INIT();
    /* Init TSI moudle*/
    TSI_init();
    /* Calibrate TSI idle value, save as TSI baseline */
    TSI_keyCalibrate();

    while (1)
    {
        /* debug key function */
        key_event = TSI_keyDetect(&touched_key_id);

        if (key_event == kKey_Event_Touch)
        {
            /* if (touched_key_id == 0) */
            {
                LED1_ON();
                PRINTF("TSI key touched.\r\n");
            }
        }
        else if (key_event == kKey_Event_Release)
        {
            /* if (touched_key_id == 0) */
            {
                LED1_OFF();
                PRINTF("TSI key released.\r\n");
            }
        }
        else
        {
            /* Here to deal with other key events */
            key_event = kKey_Event_Idle;
        }
    }
}
